@@ -9,7 +9,7 @@ function(object, ...) {
             "_.", sep = ""), generaldesigneffect(object$weightvec))
     names(part1list) <- namer
     part2list <- weightassess(object$targets, object$dataframe, 
-        object$weightvec)
+        object$weightvec, object$prevec)
     out <- c(part1list, part2list)
     out
 }
